@@ -21,7 +21,7 @@
 
 """
 __author__ = """\n""".join(['Thomas Cokelaer <cokelaer@ebi.ac.uk'])
-__all__ = ['RPackage']
+__all__ = ['RPackage', 'biocLite']
 
 import logging
 import os
@@ -29,23 +29,44 @@ import rpy2
 from rpy2 import robjects
 from rpy2.robjects import rinterface
 from rpy2.robjects.packages import importr
-#from rpy2.robjects import r
 from distutils.version import StrictVersion
  
 from error import Rwarning, RRuntimeError
 
 
-import_error = """RTOOLS: could not import R package %s. Try to install it. If you have the source file, you can try to type:
+import_error = """RTOOLS: could not import R package %s. 
+
+If you have the source file, you can try to type:
 
     R CMD INSTALL package_name.tar.gz
 
-or if it is available on BioConductor, type:
+in a R session. If it is a BioConductor package, type:
 
     source("http://bioconductor.org/biocLite.R")
     biocLite("package_name.tar.gz")
 
+You can also install it from python::
+
+	from rtools import biocLite
+        biocLite("CellNOptR")
+
  """ 
 
+def biocLite(package):
+    """Install a package bioconductor
+
+    :param str package: name of the bioconductor package to install
+
+    ::
+
+        >>> from rcode import biocLite
+        >>> biocLite("CellNOptR")
+
+    """
+    from tools import rcode
+    rcode("""source("http://bioconductor.org/biocLite.R"); biocLite("%s") """ % package)
+
+
 
 class RPackage(object):
     """simple class to import a R package and get metainfo
